/* PlaylistItemModel.h */

/* Copyright (C) 2011  Lucio Carreras
 *
 * This file is part of sayonara player
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/*
 * PlaylistItemModel.h
 *
 *  Created on: Apr 8, 2011
 *      Author: luke
 */

#ifndef PLAYLISTITEMMODEL_H_
#define PLAYLISTITEMMODEL_H_

#include "GUI/Helper/SearchableWidget/AbstractSearchModel.h"

#include "Helper/MetaData/MetaData.h"
#include "GUI/Helper/CustomMimeData.h"

#include <QUrl>
#include <QLabel>
#include <QAbstractListModel>
#include <QStringList>



class PlaylistItemModel : public AbstractSearchListModel {
	Q_OBJECT
public:
	PlaylistItemModel(QObject* parent=nullptr);

	virtual ~PlaylistItemModel();

	virtual int rowCount(const QModelIndex &parent=QModelIndex()) const override;
	virtual QVariant data(const QModelIndex &index, int role=Qt::DisplayRole) const override;

	virtual Qt::ItemFlags flags(const QModelIndex &index) const override;

	virtual bool setData(const QModelIndex &index, const QVariant &value, int role=Qt::DisplayRole) override;
	virtual bool setData(const QModelIndex &index, const MetaData &md, int role=Qt::DisplayRole);

	virtual bool insertRows(int position, int rows, const QModelIndex &index=QModelIndex()) override;
	virtual bool removeRows(int position, int rows, const QModelIndex &index=QModelIndex()) override;

	virtual QModelIndex getFirstRowIndexOf(QString substr) override;
	virtual QModelIndex getPrevRowIndexOf(QString substr, int row, const QModelIndex &parent=QModelIndex()) override;
	virtual QModelIndex getNextRowIndexOf(QString substr, int row, const QModelIndex &parent=QModelIndex()) override;
	virtual QMap<QChar, QString> getExtraTriggers() override;

	void set_selected(const IdxList& rows);
	bool is_selected(int row) const ;

	void get_metadata(const IdxList& rows, MetaDataList& v_md);
	CustomMimeData* get_custom_mimedata(const QModelIndexList& indexes) const;
	QMimeData* mimeData(const QModelIndexList& indexes) const override;


protected:
	MetaDataList		_v_meta_data;
	IdxList				_selected_rows;

};

#endif /* PLAYLISTITEMMODEL_H_ */
